﻿using System.Diagnostics;
using MSOUI.Properties;

namespace MSOUI;

internal static class Program
{
    private static void Main ()
    {
        string folder = $"{Directory.GetCurrentDirectory()}\\mso_updates\\";
        if (!Directory.Exists (folder))
        {
            Console.WriteLine(Resources.FolderNotExist, folder);
            Console.ReadLine ();
            return;
        }
        string Mask = "*.exe";
        List<string> fileList = new();
        ScanForFiles(ref fileList, folder, Mask);
        Console.WriteLine(Resources.StartUpdateMessage);
        string? isAcceptStr = Console.ReadLine();
        if ((isAcceptStr ?? "n").ToLower() == "y")
            InstallUpdates(ref fileList, folder);
        Console.WriteLine(Resources.ProgramIsFinish);
        Console.ReadLine();
    }
    public static void StartProcess (string fileName)
    {
        Process process = new();
        process.StartInfo.FileName = fileName;
        process.StartInfo.Arguments = "/q /norestart";
        process.StartInfo.CreateNoWindow = false;
        process.EnableRaisingEvents = true;
        process.Exited += (_, _) => Console.WriteLine(Resources.ProcessWasFinishedWithCode, process.ExitTime, process.ExitCode);
        process.Start();
        process.WaitForExit();
    }
    public static void InstallUpdates (ref List<string> fileList, string folder)
    {
        Console.WriteLine(Resources.StartingUpdate);

        int updatesCount = fileList.Count;

        Console.WriteLine(Resources.UpdateCountMessage, updatesCount);

        int count = 0;

        foreach (string? file in fileList)
        {
            count++;

            decimal percentDone = Math.Round((decimal)count / updatesCount * 100);

            Console.WriteLine(Resources.UpdatingFile, file, count, updatesCount, percentDone);
            StartProcess($"{folder}{file}");
            Console.WriteLine(Resources.FileWasUpdated, file);
        }
    }
    public static void ScanForFiles (ref List<string> fileList, string folder, string mask)
    {
        Console.WriteLine(Resources.SearchStarted);
        Console.WriteLine($@"	 {folder}");
        Console.WriteLine(Resources.ListOfFoundFiles);
        foreach (string fFile in Directory.EnumerateFiles(folder, mask, SearchOption.AllDirectories))
        {
            try
            {
                FileInfo fInfo = new(fFile);
                fileList.Add(fInfo.Name);
                Console.WriteLine($@"	 {fInfo.Name}");
            }
            catch
            {
                // ignored
            }
        }
    }
}