﻿using msoui.Enums;
using msoui.Models;

using SevenZipExtractor;

namespace msoui.Forms;
public sealed partial class UnPackForm: Form
{
    public UnPackForm (UnPackModel model)
    {
        Model = model;
        FileList = new();
        InitializeComponent();
    }

    private const string MessageUnPackFile = "Распаковывается файл {0}...";

    public UnPackModel Model { get; set; }

    public List<string> FileList { get; set; }


    private void UnPackThis()
    {
        //Создаю папку
        Directory.CreateDirectory(Model.UnPackDir);

        //Папка, которая отсеивается
        string unFolderName = Model.Bits == EBits.Bit32 ? "x64" : "x32";

        //Открываю архив
        using ArchiveFile archiveFile = new(Model.DataFile);

        //Создаю список на извлечение
        List<Entry> extractList = new();

        //Обхожу список и отсеиваю ненужные
        foreach (Entry entry in archiveFile.Entries)
        {
            //Если папка
            if (entry.IsFolder)
            {
                //то проверяем нужную разрядность
                if (entry.FileName != unFolderName)
                    //если да, то добавляем в список для извлечения
                    extractList.Add(entry);
            }
            else
            {
                //если это файл, то проверяем на нахождение в нужной папке
                if (entry.FileName[..3] == unFolderName)
                    continue;

                //и добавляем в список, если нужной
                extractList.Add(entry);
            }
        }

        //Устанавливаю максимальное значение индикатора прогресса
        progressBar.Maximum = extractList.Count;

        //Извлекаю архив
        foreach (Entry entry in extractList)
        {
            //Формирую имя файла назначения
            string unPackFileName;
            try
            {
                 unPackFileName = entry.FileName[4..];
            }
            catch (Exception)
            {
                unPackFileName = "UnNamed";
            }

            //Вывожу сообщение
            waitLabel.Text = string.Format(MessageUnPackFile, unPackFileName);
            Application.DoEvents();

            //Распаковываю файл
            //entry.Extract($@"{unPackTo}{unPackFileName}");

            //Добавляю в список файлов
            if (File.Exists($@"{Model.UnPackDir}{unPackFileName}"))
                FileList.Add(unPackFileName);

            //Добавляю деление в индикатор прогресса
            progressBar.Value++;
        }

        //Выхожу
        DialogResult = DialogResult.OK;
    }

    private void startTimer_Tick (object sender, EventArgs e)
    {
        startTimer.Enabled = false;
        UnPackThis();
    }

    private void UnPackForm_Load (object sender, EventArgs e)
    {
        startTimer.Enabled = true;
    }
}
